pkgs: {
  enable = true;
  profiles = {
    "default" = {
      id = 0;

      search = {
        default = "duckduckgo";
        privateDefault = "duckduckgo";
        engines = {
          "ddg".metaData.hidden = true;
          "google".metaData.hidden = true;
          "amazondotcom-us".metaData.hidden = true;
          "bing".metaData.hidden = true;
          "wikipedia".metaData.hidden = true;
          duckduckgo = {
            urls = [
              {
                template = "https://duckduckgo.com/";
                params = [
                  {
                    name = "q";
                    value = "{searchTerms}";
                  }
                ];
              }
            ];
            definedAliases = ["@ddg"];
          };
          google = {
            urls = [
              {
                template = "https://google.com/search";
                params = [
                  {
                    name = "q";
                    value = "{searchTerms}";
                  }
                ];
              }
            ];
            definedAliases = ["@g"];
          };
          wikipedia = {
            urls = [
              {
                template = "https://en.wikipedia.org/wiki/Special:Search";
                params = [
                  {
                    name = "search";
                    value = "{searchTerms}";
                  }
                ];
              }
            ];
            definedAliases = ["@wiki"];
          };
          youtube = {
            urls = [
              {
                template = "https://youtube.com/results";
                params = [
                  {
                    name = "search_query";
                    value = "{searchTerms}";
                  }
                ];
              }
            ];
            definedAliases = ["@yt"];
          };
          nix-packages = {
            urls = [
              {
                template = "https://search.nixos.org/packages";
                params = [
                  {
                    name = "channel";
                    value = "unstable";
                  }
                  {
                    name = "type";
                    value = "packages";
                  }
                  {
                    name = "query";
                    value = "{searchTerms}";
                  }
                ];
              }
            ];
            definedAliases = ["@np"];
          };
          nix-options = {
            urls = [
              {
                template = "https://search.nixos.org/options";
                params = [
                  {
                    name = "channel";
                    value = "unstable";
                  }
                  {
                    name = "type";
                    value = "packages";
                  }
                  {
                    name = "query";
                    value = "{searchTerms}";
                  }
                ];
              }
            ];
            definedAliases = ["@no"];
          };
          nix-wiki = {
            urls = [
              {
                template = "https://wiki.nixos.org/w/index.php";
                params = [
                  {
                    name = "search";
                    value = "{searchTerms}";
                  }
                ];
              }
            ];
            definedAliases = ["@nw"];
          };
          arch-wiki = {
            urls = [
              {
                template = "https://wiki.archlinux.org/index.php";
                params = [
                  {
                    name = "search";
                    value = "{searchTerms}";
                  }
                  {
                    name = "fulltext";
                    value = "1";
                  }
                ];
              }
            ];
            definedAliases = ["@aw"];
          };
          github = {
            urls = [
              {
                template = "https://github.com/search";
                params = [
                  {
                    name = "q";
                    value = "{searchTerms}";
                  }
                  {
                    name = "type";
                    value = "repositories";
                  }
                ];
              }
            ];
            definedAliases = ["@gh"];
          };
        };
        force = true;
        order = [
          "duckduckgo"
          "google"
          "wikipedia"
          "youtube"
          "nix-packages"
          "nix-options"
          "nix-wiki"
          "arch-wiki"
          "github"
        ];
      };

      bookmarks = {
        force = true;
        settings = [];
      };

      settings = {
        "browser.aboutConfig.showWarning" = false;
        "browser.bookmarks.addedImportButton" = false;
        "browser.link.open_newwindow" = 2;
        "browser.newtabpage.enabled" = false;
        "browser.preferences.moreFromMozilla" = false;
        "browser.shell.checkDefaultBrowser" = false;
        "browser.startup.blankWindow" = true;
        "browser.startup.page" = 3;
        "browser.tabs.closeWindowWithLastTab" = true;
        "browser.tabs.opentabfor.middleclick" = false;
        "browser.toolbars.bookmarks.visibility" = "never";
        "browser.translation.enable" = false;
        "dom.security.https_only_mode" = true;
        "extensions.pocket.enabled" = false;
        "gfx.webrender.all" = true;
        "identity.fxaccounts.enabled" = false;
        "media.cache_readhead_limit" = 9999;
        "media.cache_resume_threshold" = 9999;
        "medai.ffmpeg.vaapi.enabled" = true;
        "media.videocontrols.picture-in-picture.enabled" = false;
        "signon.rememberSignons" = false;
        "toolkit.legacyUserProfileCustomizations.stylesheets" = true;
      };

      extensions.packages = with pkgs.nur.repos.rycee.firefox-addons; [
        bitwarden
        sponsorblock
        ublock-origin
        pronoundb
        youtube-nonstop
        enhancer-for-youtube
        firefox-color
        purpleadblock
      ];

      userChrome = ''
        #TabsToolbar-customization-target { visibility: collapse !important; }
      '';
    };
  };
}
