{
  config,
  lib,
  pkgs,
  ...
}: let
  inherit (lib) mkIf mkMerge;
  cfg = config.conf.matrix;
in
  mkIf cfg.enable (mkMerge [
    {
      services.nginx = {
        virtualHosts = {
          ${cfg.domain.base} = {
            useACMEHost = cfg.domain.base;
            forceSSL = true;
            locations = {
              "/.well-known/matrix/" = {
                proxyPass = "http://localhost:${toString cfg.port}";
              };
            };
          };
          ${cfg.domain.full} = {
            useACMEHost = cfg.domain.base;
            forceSSL = true;
            locations = {
              "/" = {
                proxyPass = "http://localhost:${toString cfg.port}";
              };
            };
          };
        };
      };

      services.matrix-conduit = {
        enable = true;
        settings.global = {
          server_name = cfg.domain.full;
          allow_registration = false;
          port = cfg.port;
          address = "127.0.0.1";
        };
      };

      networking.firewall.allowedTCPPorts = [8448];
    }
    (mkIf
      cfg.element-web.enable
      {
        services.nginx.virtualHosts.${cfg.element-web.domain} = {
          useACMEHost = cfg.domain.base;
          forceSSL = true;

          root = pkgs.element-web.override {
            conf = {
              default_server_config = {
                "m.homeserver" = {
                  base_url = "https://${cfg.domain.full}";
                  server_name = cfg.domain.full;
                };
              };
              default_theme = "dark";
              disable_custom_urls = true;
            };
          };
        };
      })
  ])
